inspect

package
v1.6.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() tea.Model

func NewWithFile added in v1.2.0

func NewWithFile(path string) tea.Model

NewWithFile returns an inspect Model pre-loaded with the given file, skipping the file-picker step. If the file is a PFX/P12, the model advances to the password prompt instead of attempting to inspect.

func NewWithFileEmbedded added in v1.2.0

func NewWithFileEmbedded(path string) tea.Model

NewWithFileEmbedded returns an Inspect model that skips rendering the banner and title, so it can be composed inside another sub-screen (e.g. remote).

Types

type CertInfo

type CertInfo struct {
	CN, Subject, Issuer         string
	NotBefore, NotAfter         string
	Serial, Fingerprint         string
	SigAlg, KeyType, KeySize    string
	SANs                        string
	KeyUsage, ExtKeyUsage       string
	BasicConstraints            string
	CertType, Valid, ValidColor string

	// Full view fields
	Version         string
	AuthorityKeyID  string
	SubjectKeyID    string
	AIACAIssuers    string
	AIAOCSP         string
	CRLDistPoints   string
	CertPoliciesOID string
	CertPoliciesCPS string
	SignatureValue  string
}

type Model

type Model struct {
	// contains filtered or unexported fields
}

func (*Model) Init

func (m *Model) Init() tea.Cmd

func (*Model) Update

func (m *Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (*Model) View

func (m *Model) View() string

Jump to